@@ -298,14 +298,14 @@ void PhonedevTrunk::getEvents(void)
 		time(&now);
 		if(now - lastring < 4)
 		{
-			setSymbol("ringid", 4);
-			cp = getSymbol("ringid");
+			setSymbol(SYM_RINGID, 4);
+			cp = getSymbol(SYM_RINGID);
 			if(cp)
 				ringid = atoi(cp);
 			else
 				ringid = 0;
 			sprintf(buf, "%d", ++ringid);
-			setSymbol("ringid", buf);
+			setSymbol(SYM_RINGID, buf);
 			exc.bits.pstn_ring = 0;
 //			exc.bits.caller_id = 1;
 		}
@@ -445,18 +445,18 @@ void PhonedevTrunk::getEvents(void)
 			buf[cid.ixjcid.numlen] = 0;
 			if(cid.ixjcid.numlen)
 			{
-				setSymbol("callertype", 4);
-				setSymbol("callertype", "cid");
-				setSymbol("caller", 11);
-				setSymbol("caller", buf);
-				setConstant("callerid", buf);
+				setSymbol(SYM_CALLERTYPE, 4);
+				setSymbol(SYM_CALLERTYPE, "cid");
+				setSymbol(SYM_CALLER, 11);
+				setSymbol(SYM_CALLER, buf);
+				setConstant("cid", buf);
 			}
 			strncpy(buf, cid.ixjcid.name, cid.ixjcid.namelen);
 			buf[cid.ixjcid.namelen] = 0;
 			if(cid.ixjcid.namelen)
 			{
-				setSymbol("callername", 80);
-				setSymbol("callername", buf);
+				setSymbol(SYM_CALLERNAME, 80);
+				setSymbol(SYM_CALLERNAME, buf);
 			}
 			if(cid.ixjcid.numlen)
 				flags.dsp = DSP_MODE_INACTIVE;
