@@ -65,6 +65,7 @@ Keydata("/bayonne/pika")
 {
 	static KEYDEF defkeys[] = {
 	{"buffers", "2"},
+	{"ringdebounce", "60"},
 	{NULL, NULL}};
 
 	Load(defkeys);
@@ -104,6 +105,8 @@ Driver()
 			continue;
 		}
 
+		PK_TRUNK_SetRingDetect(id, pikaivr.getRingDebounce());
+
 		if(PK_MVIP_Initialize(id))
 		{
 			slog(SLOG_ERROR) << getCardName(id) << ": mvip failed" << endl;
@@ -161,7 +164,7 @@ PikaDriver::~PikaDriver()
 	if(groups)
 		delete groups;
 
-	delete PikaTrunk::status;
+	delete[] PikaTrunk::status;
 	PikaTrunk::status = NULL;
 }
 
