@@ -65,13 +65,15 @@ PikaPlay::~PikaPlay()
 	Terminate();
 
 	sprintf(buffer, "%ld", getPosition());
-	trunk->setSymbol("played", buffer);
+	trunk->setSymbol(SYM_PLAYED, buffer);
 	Close();
 	if(reset)
 	{
 		PK_AUDIO_Reset(hDsp);
 		dspReset();
 	}
+	else
+		PK_AUDIO_Stop(hDsp);
 }
 
 char *PikaPlay::getContinuation(void)
@@ -114,11 +116,11 @@ void PikaPlay::Initial(void)
 	sprintf(buffer, "%04d%02d%02d,%02d%02d%02d",
 		dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday,
 		dt->tm_hour, dt->tm_min, dt->tm_sec);
-	trunk->setSymbol("created", buffer);
+	trunk->setSymbol(SYM_CREATED, buffer);
 
 	ann = getAnnotation();
 	if(ann)
-		trunk->setSymbol("annotation", ann);
+		trunk->setSymbol(SYM_ANNOTATION, ann);
 
 	rate = getSampleRate();
 	switch(getEncoding())
@@ -189,6 +191,7 @@ void PikaPlay::Run(void)
 	int len = 0;
 	audioerror_t status = AUDIO_SUCCESS;
 	char name[33];
+	int delay;
 
 	reset = true;
 	trunk->getName(name);
@@ -215,7 +218,8 @@ void PikaPlay::Run(void)
 		PK_AUDIO_OutputAddBuffer(hDsp, &control[frame++]);		
 	}
 	
-	if(status == AUDIO_SUCCESS)
+	delay = frame;
+	if(frame > 0)
 	{
 		setAudio();
 		PK_AUDIO_OutputStart(hDsp);
@@ -242,7 +246,6 @@ void PikaPlay::Run(void)
 			frame = 0;
 	}
 
-	PK_AUDIO_Stop(hDsp);
 	reset = false;
 	clrAudio();
 	if(status == AUDIO_READ_FAILURE)
@@ -250,6 +253,7 @@ void PikaPlay::Run(void)
 		slog(SLOG_ERROR) << name << ": failed playback" << endl;
 		Failure();
 	}
+	Sleep(delay * 120l);
 	Success();
 }
 
@@ -264,7 +268,7 @@ bool PikaTrunk::playHandler(TrunkEvent *event)
 		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
-		setSymbol("error", "play-failed");
+		setSymbol(SYM_ERROR, "play-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
 		handler = &PikaTrunk::stepHandler;
 		return true;
@@ -281,7 +285,13 @@ bool PikaTrunk::playHandler(TrunkEvent *event)
 	case TRUNK_OFF_HOOK:
 	case TRUNK_TIMER_EXPIRED:
 		endTimer();
-		getVPResource();
+		if(!getVPResource())
+		{
+			setSymbol(SYM_ERROR, "dsp-unavailable");
+			TrunkSignal(TRUNK_SIGNAL_ERROR);
+			handler = &PikaTrunk::stepHandler;
+			return true;
+		}
 		Trunk::setDTMFDetect();
 		thread = new PikaPlay(this);
 		thread->Start();
