@@ -94,54 +94,58 @@ PikaTrunk::~PikaTrunk()
 	delete[] buffers;
 }
 
-void PikaTrunk::getCIDResource(void)
+bool PikaTrunk::getCIDResource(void)
 {
 	int rtn;
 
 	if(flags.dsp != DSP_MODE_INACTIVE)
-		return;
+		return false;
 
 	if(nti != TRUNK_LS_NTI)
-		return;
+		return false;
 
 	hDsp = pikaivr.getDSPResource(card, PK_CALLER_ID);
 	if(!hDsp)
-		return;
+		return false;
 
 
 	if(PK_MVIP_FullDuplexConnect(hTrk, hDsp))
 	{
 		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": cannot connect cid resource" << endl;
- 		return;
+ 		return false;
 	}
 	PK_DSP_SetEventHandler(hDsp, id, (pikacall_t)&PikaTrunk::callback);
 
 	rtn = PK_CID_SetBuffer(hDsp, cidbuf, PK_CID_BUFFER_SIZE);
 	PK_CID_SetTimeOut(hDsp, PK_CID_DEFAULT_TIME_OUT);	
 	if(PK_CID_Enable(hDsp))
+	{
 		slog(SLOG_DEBUG) << pikaivr.getCardName(card) << id << ": cannot activate callerid" << endl;
-	else
-		flags.dsp = DSP_MODE_CALLERID;
+		return false;
+	}
+	flags.dsp = DSP_MODE_CALLERID;
+	return true;
 }
 
-void PikaTrunk::getVPResource(void)
+bool PikaTrunk::getVPResource(void)
 {
 	if(flags.dsp == DSP_MODE_VOICE)
-		return;
+		return true;
 
 	stopDSP();
 	hDsp = pikaivr.getDSPResource(card, PK_VP_RESOURCES);
 	if(!hDsp)
-		return;
+		return false;
 
 	if(PK_MVIP_FullDuplexConnect(hTrk, hDsp))
 	{
 		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": mvip connect failure" << endl;
-		return;
+		return false;
 	}
 
 	flags.dsp = DSP_MODE_VOICE;
 	PK_DSP_SetEventHandler(hDsp, id, (pikacall_t)&PikaTrunk::callback);
+	return true;
 }	
 
 void PikaTrunk::setDTMFDetect(bool flag)
