@@ -28,7 +28,7 @@ VPBPlay::~VPBPlay()
 	char buffer[12];
 	Terminate();
 	sprintf(buffer, "%d", getPosition());
-	trunk->setSymbol("played", buffer);
+	trunk->setSymbol(SYM_PLAYED, buffer);
 	Close();
 	if(reset)
 	{
@@ -65,10 +65,10 @@ void VPBPlay::Initial(void)
 	sprintf(buffer, "%04d%02d%02d,%02d%02d%02d",
 		dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday,
 		dt->tm_hour, dt->tm_min, dt->tm_sec);
-	trunk->setSymbol("created", buffer);
+	trunk->setSymbol(SYM_CREATED, buffer);
 	ann = getAnnotation();
 	if(ann)
-		trunk->setSymbol("annotation", ann);
+		trunk->setSymbol(SYM_ANNOTATION, ann);
 	
 	switch(getEncoding())
 	{
@@ -139,7 +139,7 @@ bool VPBTrunk::playHandler(TrunkEvent *event)
 		handler = &VPBTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
-		setSymbol("error", "play-failed");
+		setSymbol(SYM_ERROR, "play-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
 		handler = &VPBTrunk::stepHandler;
 		return true;
