@@ -142,7 +142,8 @@ retry:
 		goto retry;
 		break;
 	case TRUNK_TIMER_EXPIRED:
-		TrunkSignal(TRUNK_SIGNAL_TIMEOUT);
+		if(!TrunkSignal(TRUNK_SIGNAL_TIMEOUT))
+			TrunkSignal(TRUNK_SIGNAL_STEP);
 		event->id = TRUNK_STOP_STATE;
 		goto retry;
 		break;
