@@ -187,14 +187,6 @@ Sync::Sync()
 	time(&runtime);
 }
 
-Database::Database()
-{
-	if(database)
-		throw this;
-
-	database = this;
-}
-
 Server::Server(int pri) :
 Thread(NULL, pri, keythreads.getStack())
 {
@@ -230,15 +222,6 @@ PortManager::PortManager(Trunk *trk)
 	trunk->manager = this;
 }
 
-StatMon::StatMon() : 
-Keydata("/bayonne/statmon")
-{
-	if(statmon)
-		throw this;
-	statmon = this;
-	Load("~bayonne/statmon");
-}
-
 TGI::TGI()
 {
 	next = first;
@@ -298,8 +281,6 @@ Module *getModule(modtype_t mtype, const char *name)
 	}
 	return NULL;
 }
-	
+
 Debug *debug = NULL;
 Driver *driver = NULL;
-StatMon *statmon = NULL;
-Database *database = NULL;
