@@ -75,11 +75,7 @@ void Scheduler::Run(void)
 	Update();
 	for(;;)
 	{
-		if(statmon)
-			statmon->Refresh(60);
-		else
-			Sleep(60000);
-
+		Sleep(60000);
 		Session::Clean();
 		time(&now);
 		sync = Sync::first;
