@@ -28,8 +28,8 @@ bool Trunk::scrRecord(void)
 	data.record.timeout = (timeout_t)getTimeout() * 1000l;
 	data.record.term = getDigitMask();
 	data.record.offset = 0;
-	data.record.volume = atoi(getSymbol("volume"));
-	data.record.trim = atoi(getSymbol("trim"));
+	data.record.volume = atoi(getSymbol(SYM_VOLUME));
+	data.record.trim = atoi(getSymbol(SYM_TRIM));
 	data.record.append = false;
 	TrunkStep(TRUNK_STEP_RECORD);
 	return false;
@@ -47,8 +47,8 @@ bool Trunk::scrAppend(void)
 	data.record.timeout = (timeout_t)getTimeout() * 1000l;
 	data.record.term = getDigitMask();
 	data.record.offset = 0;
-	data.record.volume = atoi(getSymbol("volume"));
-	data.record.trim = atoi(getSymbol("trim"));
+	data.record.volume = atoi(getSymbol(SYM_VOLUME));
+	data.record.trim = atoi(getSymbol(SYM_TRIM));
 	data.record.append = true;
 	TrunkStep(TRUNK_STEP_RECORD);
 	return false;
@@ -76,7 +76,7 @@ bool Trunk::scrSpeak(void)
 	Translator *tts;
 	char *err;
 
-	tts = getTranslator(getSymbol("language"));
+	tts = getTranslator(getSymbol(SYM_LANGUAGE));
 
 	if(!tts)
 	{
@@ -92,7 +92,7 @@ bool Trunk::scrSpeak(void)
 	while(*data.play.name == ',')
 		++data.play.name;
 
-	data.play.volume = atoi(getSymbol("volume"));
+	data.play.volume = atoi(getSymbol(SYM_VOLUME));
 	TrunkStep(TRUNK_STEP_PLAY);
 	return false;
 }
@@ -125,7 +125,7 @@ bool Trunk::scrPlay(void)
 	str << ends;
 	data.play.list[sizeof(data.play.list) - 1] = 0;
 	data.play.name = data.play.list;
-	data.play.volume = atoi(getSymbol("volume"));
+	data.play.volume = atoi(getSymbol(SYM_VOLUME));
 	while(*data.play.name == ',')
 		++data.play.name;
 
