@@ -22,9 +22,9 @@
 #include <sys/mman.h>
 #endif
 
+int mainpid;
 int tgipipe[2];
 static int *tgipids = NULL;
-static int mainpid;
 static Resolver *resolver = NULL;
 
 #ifndef	HAVE_SETENV
@@ -278,10 +278,13 @@ static void initial(int argc, char **argv)
 		{"test", 0, 0, 't'},
 		{"trace", 0, 0, 'T'},
 		{"version", 0, 0, 'V'},
+		{"gui", 0, 0, 'G'},
+		{"display", 1, 0, 'X'},
 		{0, 0, 0, 0}};
 
 	static bool daemon = false;
 	static bool usage = false;
+	static bool gui = false;
 
 	mainpid = getpid();
 	char prefix[256];
@@ -300,9 +303,15 @@ static void initial(int argc, char **argv)
 	pthread_sigmask(SIG_BLOCK, &sigs, NULL);
 	slog.level(SLOG_NOTICE);
 
-	while(EOF != (opt = getopt_long(argc, argv, "TDFhd:p:d:tn:", long_options, &opt_index)))
+	while(EOF != (opt = getopt_long(argc, argv, "GTDFX:hd:p:d:tn:", long_options, &opt_index)))
 		switch(opt)
 		{
+		case 'X':
+			setenv("DISPLAY", optarg, 1);
+		case 'G':
+			gui = true;
+			plugins.setValue("debug", "gui");
+			break;			
 		case 'V':
 			cout << LIB_VERSION << endl;
 			exit(0);
@@ -334,7 +343,10 @@ static void initial(int argc, char **argv)
 			plugins.setValue("auditing", prefix);
 			strcpy(pp, "/modules/translators/english.tts");
 			plugins.setValue("languages", prefix);
-			strcpy(pp, "/server/test.dbg");
+			if(gui)
+				strcpy(pp, "/modules/gui/gui.dbg");
+			else
+				strcpy(pp, "/server/test.dbg");
 			plugins.setValue("debug", prefix);
 			strcpy(pp, "/data/script");
 			keypaths.setValue("scripts", prefix);
@@ -364,7 +376,7 @@ static void initial(int argc, char **argv)
 
 	if(optind < argc)
 	{
-		if(test)
+		if(test && !gui)
 		{
 			strcpy(pp, "/modules/auditing/trace.dbg");
 			plugins.setValue("debug", prefix);
@@ -399,6 +411,9 @@ static void initial(int argc, char **argv)
 		close(1);
 		close(2);
 		pdetach();
+		mainpid = getpid();
+		slog.open("bayonne", SLOG_DAEMON);
+		slog(SLOG_NOTICE) << "daemon mode started" << endl;
 	}
 
 	sprintf(prefix, "%s/tgi", keypaths.getLibexec());
@@ -536,7 +551,10 @@ int main(int argc, char **argv)
 	fifo.open(buffer);
 	slog(SLOG_DEBUG) << "fifo: path=" << buffer << endl;
 	if(!fifo.is_open())
+	{
+		slog(SLOG_WARNING) << "fifo: open failed" << endl;
 		sleep(-1);
+	}
 
 	chown(buffer, keyserver.getUid(), keyserver.getGid());
 
