@@ -64,6 +64,9 @@ private:
 	time_t last;
 	char *getPath(void);
 	statnode_t *getNode(const char *name);
+	struct sockaddr bcast;
+	struct sockaddr_in *broadcast;
+
 	void Initial(void);
 	void Run(void);
 
@@ -90,6 +93,23 @@ public:
 	Resolver();
 };
 
+#define	SYM_ANNOTATION	"annotation"
+#define	SYM_PLAYED	"played"
+#define	SYM_RECORDED	"recorded"
+#define	SYM_CREATED	"created"
+#define	SYM_EXTENSION	"extension"
+#define	SYM_LANGUAGE	"language"
+#define	SYM_TRIM	"trim"
+#define	SYM_VOICE	"voice"
+#define	SYM_VOLUME	"volume"
+#define	SYM_FORMAT	"format"
+#define	SYM_ERROR	"error"
+#define	SYM_CALLERTYPE	"callertype"
+#define	SYM_CALLERNAME	"callername"
+#define	SYM_CALLER	"caller"
+#define	SYM_RINGID	"ringid"
+
 extern Network network;
 extern Scheduler scheduler;
 extern int tgipipe[2];
+extern int mainpid;
