@@ -217,25 +217,25 @@ bool Trunk::Attach(const char *name)
 		return false;
 	
 	flags.script = true;
-	setSymbol("annotation", 160);
-	setSymbol("played", 12);
-	setSymbol("recorded", 12);
-	setSymbol("created", 20);
+	setSymbol(SYM_ANNOTATION, 160);
+	setSymbol(SYM_PLAYED, 12);
+	setSymbol(SYM_RECORDED, 12);
+	setSymbol(SYM_CREATED, 20);
 
-	setSymbol("extension", 8);
-	setSymbol("extension", cmd->getLast("extension"));
+	setSymbol(SYM_EXTENSION, 8);
+	setSymbol(SYM_EXTENSION, cmd->getLast("extension"));
 	
-	setSymbol("trim", 8);
-	setSymbol("trim", "600");
+	setSymbol(SYM_TRIM, 8);
+	setSymbol(SYM_TRIM, "600");
 
-	setSymbol("language", 16);
-	setSymbol("language", cmd->getLast("language"));
+	setSymbol(SYM_LANGUAGE, 16);
+	setSymbol(SYM_LANGUAGE, cmd->getLast("language"));
 
-	setSymbol("voice", 16);
-	setSymbol("voice", cmd->getLast("voice"));
+	setSymbol(SYM_VOICE, 16);
+	setSymbol(SYM_VOICE, cmd->getLast("voice"));
 
-	setSymbol("volume", 3);
-	setSymbol("volume", group->getLast("volume"));
+	setSymbol(SYM_VOLUME, 3);
+	setSymbol(SYM_VOLUME, group->getLast("volume"));
 
 	sprintf(buf, "%03d", id);
 	setConstant("id", buf);
